@@ -1,3 +1,17 @@
+# -*- coding: utf-8 -*-
+
+# Licensed under the Open Software License ("OSL") v. 3.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+
+#     http://www.opensource.org/licenses/osl-3.0.php
+
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 import os
 import sys
 sys.path.insert(0,os.path.abspath(__file__+"/../../../"))
@@ -20,5 +34,5 @@ class CheckboxUncheckAction(ActionBase):
     def execute(self, values, context):
         checkbox_name = values[0]
         checkbox = self.resolve_element_key(context, Page.Checkbox, checkbox_name)
-        self.assert_element_is_visible(checkbox, self.language["checkbox_is_visible_failure"] % checkbox_name)
+        self.assert_element_is_visible(checkbox, self.language["element_is_visible_failure"] % ("checkbox", checkbox_name))
         self.browser_driver.checkbox_uncheck(checkbox)
