@@ -1,6 +1,23 @@
+# -*- coding: utf-8 -*-
+
+# Licensed under the Open Software License ("OSL") v. 3.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+
+#     http://www.opensource.org/licenses/osl-3.0.php
+
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 import os
+from os.path import abspath, join
 import sys
-sys.path.insert(0,os.path.abspath(__file__+"/../../../"))
+sys.path.insert(0,abspath(__file__+"/../../../"))
+from pyccuracy.common import URLChecker
+from pyccuracy.errors import ActionFailedError
 from pyccuracy.page import Page
 from pyccuracy.actions.action_base import ActionBase
 from pyccuracy.actions.element_is_visible_base import *
@@ -38,13 +55,19 @@ class PageGoToAction(ActionBase):
 
         if base_url:
             url = basejoin(base_url + "/", url)
-        
+
         protocol, page_name, file_name, complement, querystring, anchor = urllib2.urlparse.urlparse(url)
-        
-        if not protocol and not base_url:
-        	url = "file://" + os.path.abspath(os.path.join(context.tests_dir, url))
-        elif not protocol:
-        	url = "file://" + os.path.abspath(url)
-        
+
+        if not protocol:
+            if not base_url and os.path.exists(abspath(join(context.tests_dir, url))):
+                url = "file://" + abspath(join(context.tests_dir, url))
+            elif os.path.exists(url):
+                url = "file://" + abspath(url)
+            else:
+                checker = URLChecker()
+                checker.set_url(url)
+                if not checker.is_valid():
+                    raise ActionFailedError(self.language['page_go_to_failure'] % url)
+
         self.browser_driver.page_open(url)
         self.browser_driver.wait_for_page()
