@@ -1,3 +1,17 @@
+# -*- coding: utf-8 -*-
+
+# Licensed under the Open Software License ("OSL") v. 3.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+
+#     http://www.opensource.org/licenses/osl-3.0.php
+
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 import os
 import sys
 sys.path.insert(0,os.path.abspath(__file__+"/../../../"))
@@ -22,9 +36,9 @@ class SelectHasSelectedIndexAction(ActionBase):
         index = values[1]
 
         select = self.resolve_element_key(context, Page.Select, select_name)
-        error_message = self.language["select_is_visible_failure"]
-        self.assert_element_is_visible(select, self.language["select_is_visible_failure"] % select_name)
-        
+        error_message = self.language["element_is_visible_failure"]
+        self.assert_element_is_visible(select, error_message % ("select", select_name))
+
         selected_index = self.browser_driver.get_selected_index(select)
 
         if (selected_index != index):
