@@ -1,3 +1,17 @@
+# -*- coding: utf-8 -*-
+
+# Licensed under the Open Software License ("OSL") v. 3.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+
+#     http://www.opensource.org/licenses/osl-3.0.php
+
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 import os
 import sys
 sys.path.insert(0,os.path.abspath(__file__+"/../../../"))
@@ -21,7 +35,7 @@ class TextboxContainsTextAction(ActionBase):
         textbox_name = values[0]
         text = values[1]
         textbox = self.resolve_element_key(context, Page.Textbox, textbox_name)
-        self.assert_element_is_visible(textbox, self.language["textbox_is_visible_failure"] % textbox_name)
+        self.assert_element_is_visible(textbox, self.language["element_is_visible_failure"] % ("textbox", textbox_name))
         
         current_text = self.browser_driver.get_element_text(textbox)
         if (not current_text) or (not text in current_text):
