@@ -1,3 +1,17 @@
+# -*- coding: utf-8 -*-
+
+# Licensed under the Open Software License ("OSL") v. 3.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+
+#     http://www.opensource.org/licenses/osl-3.0.php
+
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 import os
 import sys
 import time
@@ -5,7 +19,6 @@ import urllib2
 
 from selenium import *
 from browser_driver import *
-from selenium_server import SeleniumServer
 from selenium_element_selector import SeleniumElementSelector
 
 class SeleniumBrowserDriver(BrowserDriver):
@@ -19,12 +32,12 @@ class SeleniumBrowserDriver(BrowserDriver):
 
         return SeleniumElementSelector.element(element_type, element_key)
 
-    def start_test(self, url = "http://www.someurl.com"):
+    def start_test(self, url = "http://localhost"):
         self.selenium = selenium(self.__host__, self.__port__, self.__browser__, url)
         try:
             self.selenium.start()
         except Exception, e:
-            sys.stderr.write("Error when starting selenium. Is it running ?\n")
+            sys.stderr.write("Error when starting selenium. Is it running ? Error: %s\n" % unicode(e))
             sys.exit(1)
 
     def page_open(self, url):
@@ -48,6 +61,13 @@ class SeleniumBrowserDriver(BrowserDriver):
     def get_title(self):
         return self.selenium.get_title()
 
+    def get_xpath_count(self, xpath):
+        return self.selenium.get_xpath_count(xpath)
+
+    def get_class(self, name):
+        klass = self.__get_attribute_value(name, 'class')
+        return klass
+
     def is_element_enabled(self, element):
         script = """this.page().findElement("%s").disabled;"""
 
@@ -55,7 +75,7 @@ class SeleniumBrowserDriver(BrowserDriver):
         if script_return == "null":
             is_disabled = self.__get_attribute_value(element, "disabled")
         else:
-            is_disabled = script_return[0].upper()=="T"
+            is_disabled = script_return[0].upper()=="T" # is it 'True'?
         return not is_disabled
 
     def checkbox_is_checked(self, checkbox_selector):
@@ -80,19 +100,24 @@ class SeleniumBrowserDriver(BrowserDriver):
         text = ""
         tag_name_script = """this.page().findElement("%s").tagName;"""
         tag_name = self.selenium.get_eval(tag_name_script % element_selector).lower()
-        
+
         properties = {
                         "input" : "value",
                         "textarea" : "value",
                         "div" : "innerHTML"
                      }
-        
+
         script = """this.page().findElement("%s").%s;"""
-        script_return = self.selenium.get_eval(script % (element_selector, properties[tag_name]))
+        try:
+            # if the element is not in the dict above, I'll assume that we need to use "innerHTML"
+            script_return = self.selenium.get_eval(script % (element_selector, properties.get(tag_name, "innerHTML")))
+        except KeyError, err:
+            raise ValueError("The tag for element selector %s is %s and Pyccuracy only supports the following tags: %s",
+                             (element_selector, tag_name, ", ".join(properties.keys)))
 
         if script_return != "null":
-            text = script_return        
-        
+            text = script_return
+
         return text
 
     def get_element_markup(self, element_selector):
@@ -132,10 +157,40 @@ class SeleniumBrowserDriver(BrowserDriver):
     def mouseover_element(self, element_selector):
         self.selenium.mouse_over(element_selector)
 
+    def mouseout_element(self, element_selector):
+        self.selenium.mouse_out(element_selector)
+
     def is_element_empty(self, element_selector):
         current_text = self.get_element_text(element_selector)
         return current_text == ""
 
+    def wait_for_element_present(self, element_selector, timeout):
+        elapsed = 0
+        interval = 0.5
+
+        while (elapsed < timeout):
+            elapsed += interval
+            if self.is_element_visible(element_selector):
+                return True
+            time.sleep(interval)
+
+        return False
+
+    def wait_for_element_to_disappear(self, element_selector, timeout):
+        elapsed = 0
+        interval = 0.5
+
+        while (elapsed < timeout):
+            elapsed += interval
+            if not self.is_element_visible(element_selector):
+                return True
+            time.sleep(interval)
+
+        return False
+
+    def drag_element(self, from_element_selector, to_element_selector):
+        self.selenium.drag_and_drop_to_object(from_element_selector, to_element_selector)
+
     def stop_test(self):
         self.selenium.stop()
 
