@@ -1,3 +1,19 @@
+# -*- coding: utf-8 -*-
+
+# Licensed under the Open Software License ("OSL") v. 3.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+
+#     http://www.opensource.org/licenses/osl-3.0.php
+
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
+import urllib2
+
 from test_fixture import *
 
 class StoryRunner(object):
@@ -13,7 +29,16 @@ class StoryRunner(object):
             test_fixture.did_not_run()
             return
 
-        self.browser_driver.start_test("http://www.pyccuracy.org")
+        base_url = None
+        if self.context.base_url:
+            protocol, page_name, file_name, complement, querystring, anchor = urllib2.urlparse.urlparse(self.context.base_url)
+            base_url = protocol and self.context.base_url or None
+
+        if base_url:
+            self.browser_driver.start_test(base_url)
+        else:
+            self.browser_driver.start_test()
+
         try:
             test_fixture.start_run()
             for current_story in test_fixture.stories:
@@ -26,13 +51,21 @@ class StoryRunner(object):
 
     def __run_scenarios(self, current_story, context):
         for current_scenario in current_story.scenarios:
+            # running only the given scenarios
+            scenarios = None
+            if context.scenarios_to_run:
+                scenarios = context.scenarios_to_run.replace(" ", "").split(",")
+                if current_scenario.index not in scenarios:
+                    continue
+
             self.raise_pre_scenario(context, current_story, current_scenario)
             current_scenario.start_run()
             for current_action in (current_scenario.givens + current_scenario.whens + current_scenario.thens):
                 current_action.start_run()
                 result = current_action.execute(context)
                 current_action.end_run()
-                if not result: return 0
+                if not result:
+                    break
             current_scenario.end_run()
             self.raise_post_scenario(context, current_story, current_scenario, current_scenario.status)
 
