@@ -1,3 +1,17 @@
+# -*- coding: utf-8 -*-
+
+# Licensed under the Open Software License ("OSL") v. 3.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+
+#     http://www.opensource.org/licenses/osl-3.0.php
+
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 from errors import *
 import time
 
@@ -78,7 +92,7 @@ class Action(object):
             if (self.arguments):
                 self.execute_function(self.arguments, context)
             else:
-                self.execute_function(context)
+                self.execute_function([], context)
         except Exception, error:
             if error.__class__.__name__ != "ActionFailedError": raise
             self.mark_as_failed(error)
