@@ -1,5 +1,17 @@
 # -*- coding: utf-8 -*-
 
+# Licensed under the Open Software License ("OSL") v. 3.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+
+#     http://www.opensource.org/licenses/osl-3.0.php
+
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 import re
 from locator import *
 from test_fixture import *
@@ -77,7 +89,7 @@ class FileTestFixtureParser(object):
                     action_under = self.__process_given_when_then_line(line)
                 else:
                     if not scenario:
-                        raise RuntimeError("There is no scenario line before current action: %s" % line)
+                        raise RuntimeError(self.language["no_scenario_line_error"] % line)
                     self.__process_action_line(file_path, fixture, scenario, action_under, line)
 
     def __process_story_lines(self, fixture, as_a, i_want_to, so_that):
@@ -91,8 +103,7 @@ class FileTestFixtureParser(object):
         try:
             values = match.groups()
         except AttributeError, e:
-            raise RuntimeError(u'Could not match the line:' \
-                               ' %s\n with the regex of scenario_starter_regex - %r' % (line, unicode(e)))
+            raise RuntimeError(self.language["scenario_regex_match_error"] % (line, unicode(e)))
 
         scenario_index = values[0]
         scenario_title = values[1]
@@ -113,7 +124,7 @@ class FileTestFixtureParser(object):
             if line.strip().startswith("#"):
                 method(line, self.blank_execute, self.blank_values_for)
             else:
-                raise InvalidScenarioError("\n\n>> \"%s\"\nThe line above does not match any actions. If you just need a text like \"I wait for the page to finish loading\" or something like this, prefix your line with a # sign. \nFilename: %s\nScenario: %s - %s" % (line, file_path, scenario.index, scenario.title))
+                raise InvalidScenarioError(self.language["invalid_scenario_error"] % (line, scenario.index, scenario.title, file_path))
 
     def blank_values_for(self, line):
         return tuple([])
